# **genius.py**

[![PyPI version](https://img.shields.io/pypi/v/geniusdotpy)](https://pypi.org/project/geniusdotpy/)
[![Python 3.x version](https://img.shields.io/badge/python-3.x-brightgreen.svg)](https://www.python.org/downloads/)
[![Wiki Link](https://img.shields.io/badge/wiki-documentation-forestgreen)](https://github.com/jjoeldaniel/genius.py/wiki)

> Python wrapper for Genius API

With genius.py, enjoy an easy-to-use interface to interact with [Genius API](https://docs.genius.com)

## Table of Contents

- [Features](#features)
- [Install](#install)
- [Getting Started](#getting-started)
- [References](#references)

---

## Features

- Feature rich interface
- Easy to use
- Lyrics web scraper

## Install

```python
pip install geniusdotpy
```

## Getting Started

To get started...

1. Get your Client Access Token [here](https://genius.com/api-clients)

2. Create a new *GeniusBuilder* object

    ```python
    from geniusdotpy.genius_builder import GeniusBuilder

    genius = GeniusBuilder(client_access_token=client_access_token)
    ```

3. ???

4. Profit

## References

[Genius API](https://docs.genius.com)

[Beautiful Soup](https://www.crummy.com/software/BeautifulSoup/bs4/doc/)

---

Created with 💖 by [*jjoeldaniel*](https://github.com/jjoeldaniel)
